- dtaInp
Either a data frame or the name of a data file to be read (including the path, if required;
"FILENAME.ext"; default: NULL); files can be of any supported file type, see Details below.
- fleOut
Name of the data set / file to be written (including the path, if required; "FILE_OUT.omv";
default: ""); if empty, the resulting data frame is returned instead.
- rplLst
A list where each entry is a vector (with length 2) containing the original value and the
to-replace-value (default: list())
- whlTrm
Whether the search term (first entry in the vectors) must be found exactly (TRUE) or whether a partial
match is sufficient (FALSE; default: TRUE)
- varInc
Names of variables (character vector) to be included in the replacement (default: NULL)
- varExc
Names of variables (character vector) to be excluded from the replacement (default: NULL)
- incNum
Whether to include continuous variables in the replacement (default: TRUE)
- incOrd
Whether to include ordinal variables in the replacement (default: TRUE)
- incNom
Whether to include nominal variables in the replacement (default: TRUE)
- incID
Whether to include ID variables in the replacement (default: TRUE)
- incCmp
Whether to include Computed variables in the replacement (default: TRUE)
- incRcd
Whether to include Recoded variables in the replacement (default: TRUE)
- psvAnl
Whether analyses that are contained in the input file shall be transferred to the output file (TRUE /
FALSE; default: FALSE)
- usePkg
Name of the package: "foreign" or "haven" that shall be used to read SPSS, Stata, and SAS files;
"foreign" is the default (it is included in base R), but "haven" is newer and more comprehensive; you
may have to install using install.packages("haven", dep = TRUE).
- selSet
Name of the object / data set that is to be selected from the workspace (only relevant when reading
.RData-files which can contain several objects / data sets)
- ...
Additional arguments passed on to methods; see Details below